# ashe

✨ `ashe` is a super extension of Python.

## Install

```bash
pip install ashe
```

## Feature

1. System

   - size

2. Dict

   - merge
   - remove

3. String

   - find

## License

[![](https://award.dovolopor.com?lt=License&rt=MIT&rbc=green)](./LICENSE)
